Class: Google::Shopping::Merchant::Reports::V1beta::CompetitiveVisibilityCompetitorView

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/shopping/merchant/reports/v1beta/reports.rb

Overview

Fields available for query in competitive_visibility_competitor_view table.

Competitive visibility report with businesses with similar visibility.

Values are only set for fields requested explicitly in the request's search query.

Instance Attribute Summary collapse

Instance Attribute Details

#ads_organic_ratio::Float

Returns [Ads / organic ratio] (https://support.google.com/merchants/answer/11366442#zippy=%2Cads-free-ratio) shows how often the domain receives impressions from Shopping ads compared to organic traffic. The number is rounded and bucketed.

Cannot be filtered on in the 'WHERE' clause.

Returns:



1036
1037
1038
1039
# File 'proto_docs/google/shopping/merchant/reports/v1beta/reports.rb', line 1036

class CompetitiveVisibilityCompetitorView
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#date::Google::Type::Date

Returns Date of this row.

A condition on date is required in the WHERE clause.

Returns:



1036
1037
1038
1039
# File 'proto_docs/google/shopping/merchant/reports/v1beta/reports.rb', line 1036

class CompetitiveVisibilityCompetitorView
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#domain::String

Returns Domain of your competitor or your domain, if 'is_your_domain' is true.

Required in the SELECT clause. Cannot be filtered on in the 'WHERE' clause.

Returns:

  • (::String)

    Domain of your competitor or your domain, if 'is_your_domain' is true.

    Required in the SELECT clause. Cannot be filtered on in the 'WHERE' clause.



1036
1037
1038
1039
# File 'proto_docs/google/shopping/merchant/reports/v1beta/reports.rb', line 1036

class CompetitiveVisibilityCompetitorView
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#higher_position_rate::Float

Returns [Higher position rate] (https://support.google.com/merchants/answer/11366442#zippy=%2Chigher-position-rate) shows how often a competitor’s offer got placed in a higher position on the page than your offer.

Cannot be filtered on in the 'WHERE' clause.

Returns:



1036
1037
1038
1039
# File 'proto_docs/google/shopping/merchant/reports/v1beta/reports.rb', line 1036

class CompetitiveVisibilityCompetitorView
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#is_your_domain::Boolean

Returns True if this row contains data for your domain.

Cannot be filtered on in the 'WHERE' clause.

Returns:

  • (::Boolean)

    True if this row contains data for your domain.

    Cannot be filtered on in the 'WHERE' clause.



1036
1037
1038
1039
# File 'proto_docs/google/shopping/merchant/reports/v1beta/reports.rb', line 1036

class CompetitiveVisibilityCompetitorView
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_overlap_rate::Float

Returns [Page overlap rate] (https://support.google.com/merchants/answer/11366442#zippy=%2Cpage-overlap-rate) shows how frequently competing retailers’ offers are shown together with your offers on the same page.

Cannot be filtered on in the 'WHERE' clause.

Returns:



1036
1037
1038
1039
# File 'proto_docs/google/shopping/merchant/reports/v1beta/reports.rb', line 1036

class CompetitiveVisibilityCompetitorView
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#rank::Integer

Returns Position of the domain in the similar businesses ranking for the selected keys (date, report_category_id, report_country_code, traffic_source) based on impressions. 1 is the highest.

Cannot be filtered on in the 'WHERE' clause.

Returns:

  • (::Integer)

    Position of the domain in the similar businesses ranking for the selected keys (date, report_category_id, report_country_code, traffic_source) based on impressions. 1 is the highest.

    Cannot be filtered on in the 'WHERE' clause.



1036
1037
1038
1039
# File 'proto_docs/google/shopping/merchant/reports/v1beta/reports.rb', line 1036

class CompetitiveVisibilityCompetitorView
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#relative_visibility::Float

Returns [Relative visibility] (https://support.google.com/merchants/answer/11366442#zippy=%2Crelative-visibility) shows how often your competitors’ offers are shown compared to your offers. In other words, this is the number of displayed impressions of a competitor retailer divided by the number of your displayed impressions during a selected time range for a selected product category and country.

Cannot be filtered on in the 'WHERE' clause.

Returns:

  • (::Float)

    [Relative visibility] (https://support.google.com/merchants/answer/11366442#zippy=%2Crelative-visibility) shows how often your competitors’ offers are shown compared to your offers. In other words, this is the number of displayed impressions of a competitor retailer divided by the number of your displayed impressions during a selected time range for a selected product category and country.

    Cannot be filtered on in the 'WHERE' clause.



1036
1037
1038
1039
# File 'proto_docs/google/shopping/merchant/reports/v1beta/reports.rb', line 1036

class CompetitiveVisibilityCompetitorView
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#report_category_id::Integer

Returns Google product category ID to calculate the report for, represented in Google's product taxonomy.

Required in the SELECT clause. A condition on report_category_id is required in the WHERE clause.

Returns:

  • (::Integer)

    Google product category ID to calculate the report for, represented in Google's product taxonomy.

    Required in the SELECT clause. A condition on report_category_id is required in the WHERE clause.



1036
1037
1038
1039
# File 'proto_docs/google/shopping/merchant/reports/v1beta/reports.rb', line 1036

class CompetitiveVisibilityCompetitorView
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#report_country_code::String

Returns Country where impressions appeared.

Required in the SELECT clause. A condition on report_country_code is required in the WHERE clause.

Returns:

  • (::String)

    Country where impressions appeared.

    Required in the SELECT clause. A condition on report_country_code is required in the WHERE clause.



1036
1037
1038
1039
# File 'proto_docs/google/shopping/merchant/reports/v1beta/reports.rb', line 1036

class CompetitiveVisibilityCompetitorView
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#traffic_source::Google::Shopping::Merchant::Reports::V1beta::TrafficSource::TrafficSourceEnum

Returns Traffic source of impressions.

Required in the SELECT clause.

Returns:



1036
1037
1038
1039
# File 'proto_docs/google/shopping/merchant/reports/v1beta/reports.rb', line 1036

class CompetitiveVisibilityCompetitorView
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end