Class: Google::Shopping::Merchant::Reports::V1beta::CompetitiveVisibilityTopMerchantView

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/shopping/merchant/reports/v1beta/reports.rb

Overview

Fields available for query in competitive_visibility_top_merchant_view table.

Competitive visibility report with business with highest visibility.

Values are only set for fields requested explicitly in the request's search query.

Instance Attribute Summary collapse

Instance Attribute Details

#ads_organic_ratio::Float

Returns [Ads / organic ratio] (https://support.google.com/merchants/answer/11366442#zippy=%2Cads-free-ratio) shows how often the domain receives impressions from Shopping ads compared to organic traffic. The number is rounded and bucketed.

Cannot be filtered on in the 'WHERE' clause.

Returns:



1117
1118
1119
1120
# File 'proto_docs/google/shopping/merchant/reports/v1beta/reports.rb', line 1117

class CompetitiveVisibilityTopMerchantView
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#date::Google::Type::Date

Returns Date of this row.

Cannot be selected in the SELECT clause. A condition on date is required in the WHERE clause.

Returns:

  • Date of this row.

    Cannot be selected in the SELECT clause. A condition on date is required in the WHERE clause.



1117
1118
1119
1120
# File 'proto_docs/google/shopping/merchant/reports/v1beta/reports.rb', line 1117

class CompetitiveVisibilityTopMerchantView
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#domain::String

Returns Domain of your competitor or your domain, if 'is_your_domain' is true.

Required in the SELECT clause. Cannot be filtered on in the 'WHERE' clause.

Returns:

  • Domain of your competitor or your domain, if 'is_your_domain' is true.

    Required in the SELECT clause. Cannot be filtered on in the 'WHERE' clause.



1117
1118
1119
1120
# File 'proto_docs/google/shopping/merchant/reports/v1beta/reports.rb', line 1117

class CompetitiveVisibilityTopMerchantView
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#higher_position_rate::Float

Returns [Higher position rate] (https://support.google.com/merchants/answer/11366442#zippy=%2Chigher-position-rate) shows how often a competitor’s offer got placed in a higher position on the page than your offer.

Cannot be filtered on in the 'WHERE' clause.

Returns:



1117
1118
1119
1120
# File 'proto_docs/google/shopping/merchant/reports/v1beta/reports.rb', line 1117

class CompetitiveVisibilityTopMerchantView
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#is_your_domain::Boolean

Returns True if this row contains data for your domain.

Cannot be filtered on in the 'WHERE' clause.

Returns:

  • True if this row contains data for your domain.

    Cannot be filtered on in the 'WHERE' clause.



1117
1118
1119
1120
# File 'proto_docs/google/shopping/merchant/reports/v1beta/reports.rb', line 1117

class CompetitiveVisibilityTopMerchantView
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_overlap_rate::Float

Returns [Page overlap rate] (https://support.google.com/merchants/answer/11366442#zippy=%2Cpage-overlap-rate) shows how frequently competing retailers’ offers are shown together with your offers on the same page.

Cannot be filtered on in the 'WHERE' clause.

Returns:



1117
1118
1119
1120
# File 'proto_docs/google/shopping/merchant/reports/v1beta/reports.rb', line 1117

class CompetitiveVisibilityTopMerchantView
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#rank::Integer

Returns Position of the domain in the top merchants ranking for the selected keys (date, report_category_id, report_country_code, traffic_source) based on impressions. 1 is the highest.

Cannot be filtered on in the 'WHERE' clause.

Returns:

  • Position of the domain in the top merchants ranking for the selected keys (date, report_category_id, report_country_code, traffic_source) based on impressions. 1 is the highest.

    Cannot be filtered on in the 'WHERE' clause.



1117
1118
1119
1120
# File 'proto_docs/google/shopping/merchant/reports/v1beta/reports.rb', line 1117

class CompetitiveVisibilityTopMerchantView
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#report_category_id::Integer

Returns Google product category ID to calculate the report for, represented in Google's product taxonomy.

Required in the SELECT clause. A condition on report_category_id is required in the WHERE clause.

Returns:

  • Google product category ID to calculate the report for, represented in Google's product taxonomy.

    Required in the SELECT clause. A condition on report_category_id is required in the WHERE clause.



1117
1118
1119
1120
# File 'proto_docs/google/shopping/merchant/reports/v1beta/reports.rb', line 1117

class CompetitiveVisibilityTopMerchantView
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#report_country_code::String

Returns Country where impressions appeared.

Required in the SELECT clause. A condition on report_country_code is required in the WHERE clause.

Returns:

  • Country where impressions appeared.

    Required in the SELECT clause. A condition on report_country_code is required in the WHERE clause.



1117
1118
1119
1120
# File 'proto_docs/google/shopping/merchant/reports/v1beta/reports.rb', line 1117

class CompetitiveVisibilityTopMerchantView
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#traffic_source::Google::Shopping::Merchant::Reports::V1beta::TrafficSource::TrafficSourceEnum

Returns Traffic source of impressions.

Required in the SELECT clause.

Returns:

  • Traffic source of impressions.

    Required in the SELECT clause.



1117
1118
1119
1120
# File 'proto_docs/google/shopping/merchant/reports/v1beta/reports.rb', line 1117

class CompetitiveVisibilityTopMerchantView
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end